#ifndef VISMONITORING_DQMSERVER_VISDQMIMAGESERVER_H
# define VISMONITORING_DQMSERVER_VISDQMIMAGESERVER_H

# include "VisMonitoring/DQMServer/interface/Objects.h"
# include "DQMServices/Core/interface/DQMNet.h"
# include "classlib/iobase/Filename.h"
# include "classlib/utils/Time.h"

class DQMRenderPlugin;
struct VisDQMObject;
struct VisDQMImgInfo;
typedef std::map<std::string, VisDQMImgInfo> VisDQMImgMap;
struct VisDQMObject : DQMNet::Object
{
  VisDQMImgMap		images;
};

class VisDQMImageServer
{
public:
  static const size_t CRASH_NAME_LEN = 65536;

  typedef std::vector<DQMRenderPlugin *> RenderPlugins;
  typedef std::map<std::string, lat::Time> BlackList;

  struct ServerInfo
  {
    int			argc;
    char		**argv;
    int			port;
    bool		debug;
    char		*crashobj;
    lat::Filename	statedir;
    lat::Filename	stopfile;
    lat::Filename	blacklistFile;
    BlackList		blacklist;
  };

  VisDQMImageServer(const ServerInfo &info);
  virtual ~VisDQMImageServer(void);

protected:
  void doRender(VisDQMObject &o, VisDQMImgInfo &i);

  static bool parseInt(const char *&p, const char *name, size_t len, int &value);
  static bool parseDouble(const char *&p, const char *name, size_t len, double &value);
  static bool parseBoolean(const char *&p, const char *name, size_t len, bool &value);
  static bool parseAxisType(const char *&p, const char *name, size_t len, std::string &value);
  static bool parseOption(const char *&p, const char *name, size_t len, std::string &value);
  static VisDQMImgInfo *parseImageSpec(VisDQMObject &o, const std::string &spec, const char *&error);

  virtual std::ostream &logme(void) = 0;

private:
  RenderPlugins		plugins_;
  std::vector<bool>	applied_;

protected:
  ServerInfo		info_;
};

#endif // VISMONITORING_DQMSERVER_VISDQMIMAGESERVER_H
